"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from paygentic_sdk.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


ErrorEnum = Literal["validation_error",]
r"""Error type indicating validation failure"""


class ErrorTypedDict(TypedDict):
    field: str
    r"""The field that failed validation"""
    message: str
    r"""Validation error message for this field"""
    code: NotRequired[str]
    r"""Validation error code"""


class Error(BaseModel):
    field: str
    r"""The field that failed validation"""

    message: str
    r"""Validation error message for this field"""

    code: Optional[str] = None
    r"""Validation error code"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["code"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
