"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .creategrantrequest import CreateGrantRequest, CreateGrantRequestTypedDict
from paygentic_sdk.types import BaseModel
from paygentic_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing_extensions import Annotated, TypedDict


class CreateEntitlementGrantRequestTypedDict(TypedDict):
    entitlement_id: str
    r"""The unique identifier of the entitlement to grant credits to."""
    create_grant_request: CreateGrantRequestTypedDict


class CreateEntitlementGrantRequest(BaseModel):
    entitlement_id: Annotated[
        str,
        pydantic.Field(alias="entitlementId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The unique identifier of the entitlement to grant credits to."""

    create_grant_request: Annotated[
        CreateGrantRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
