"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from paygentic_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class LineItemsSummaryTypedDict(TypedDict):
    fee_subtotal: str
    r"""Sum of fee items with known subtotals in decimal format"""
    metered_estimated_subtotal: str
    r"""Sum of estimated metered amounts in decimal format"""
    currency: str
    r"""ISO 4217 currency code"""


class LineItemsSummary(BaseModel):
    fee_subtotal: Annotated[str, pydantic.Field(alias="feeSubtotal")]
    r"""Sum of fee items with known subtotals in decimal format"""

    metered_estimated_subtotal: Annotated[
        str, pydantic.Field(alias="meteredEstimatedSubtotal")
    ]
    r"""Sum of estimated metered amounts in decimal format"""

    currency: str
    r"""ISO 4217 currency code"""


try:
    LineItemsSummary.model_rebuild()
except NameError:
    pass
