"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from paygentic_sdk.types import BaseModel
from typing_extensions import TypedDict


class InvoiceCategorySummaryTypedDict(TypedDict):
    count: int
    r"""Number of invoices in this category"""
    amount: str
    r"""Total amount of invoices in this category in dollars"""


class InvoiceCategorySummary(BaseModel):
    count: int
    r"""Number of invoices in this category"""

    amount: str
    r"""Total amount of invoices in this category in dollars"""
