"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from paygentic_sdk.types import BaseModel
from paygentic_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing_extensions import Annotated, TypedDict


class GetSourceRuleRequestTypedDict(TypedDict):
    rule_id: str


class GetSourceRuleRequest(BaseModel):
    rule_id: Annotated[
        str,
        pydantic.Field(alias="ruleId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
