"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import Any, TYPE_CHECKING

from paygentic_sdk.utils.dynamic_imports import lazy_getattr, lazy_dir

if TYPE_CHECKING:
    from .activeentitlement import (
        ActiveEntitlement,
        ActiveEntitlementObject,
        ActiveEntitlementTypedDict,
    )
    from .address import Address, AddressTypedDict
    from .advancetestclockop import (
        AdvanceTestClockRequest,
        AdvanceTestClockRequestBody,
        AdvanceTestClockRequestBodyTypedDict,
        AdvanceTestClockRequestTypedDict,
        RequestBody1,
        RequestBody1TypedDict,
        RequestBody2,
        RequestBody2TypedDict,
    )
    from .approvesourceeventop import (
        ApproveSourceEventRequest,
        ApproveSourceEventRequestTypedDict,
    )
    from .batchcreateusageeventsop import (
        BatchCreateUsageEventsRequest,
        BatchCreateUsageEventsRequestTypedDict,
    )
    from .batchusageeventresponse import (
        BatchUsageEventResponse,
        BatchUsageEventResponseObject,
        BatchUsageEventResponseTypedDict,
        Failed,
        FailedTypedDict,
        Summary,
        SummaryTypedDict,
    )
    from .billablemetric import (
        Aggregation,
        BillableMetric,
        BillableMetricObject,
        BillableMetricTypedDict,
    )
    from .booleanentitlementdetail import (
        BooleanEntitlementDetail,
        BooleanEntitlementDetailObject,
        BooleanEntitlementDetailStatus,
        BooleanEntitlementDetailTypedDict,
    )
    from .bulkapprovesourceeventsop import (
        BulkApproveSourceEventsDetails,
        BulkApproveSourceEventsDetailsTypedDict,
        BulkApproveSourceEventsFailed,
        BulkApproveSourceEventsFailedTypedDict,
        BulkApproveSourceEventsRequest,
        BulkApproveSourceEventsRequestBody,
        BulkApproveSourceEventsRequestBodyTypedDict,
        BulkApproveSourceEventsRequestTypedDict,
        BulkApproveSourceEventsResponse,
        BulkApproveSourceEventsResponseTypedDict,
    )
    from .bulkrejectsourceeventsop import (
        BulkRejectSourceEventsRequest,
        BulkRejectSourceEventsRequestBody,
        BulkRejectSourceEventsRequestBodyTypedDict,
        BulkRejectSourceEventsRequestTypedDict,
        BulkRejectSourceEventsResponse,
        BulkRejectSourceEventsResponseTypedDict,
    )
    from .createbillablemetricop import (
        CreateBillableMetricAggregation,
        CreateBillableMetricRequest,
        CreateBillableMetricRequestTypedDict,
    )
    from .createcustomerop import (
        Consumer,
        ConsumerTypedDict,
        CreateCustomerRequest,
        CreateCustomerRequestTypedDict,
        CreateCustomerResponse,
        CreateCustomerResponseBody1,
        CreateCustomerResponseBody1TypedDict,
        CreateCustomerResponseBody2,
        CreateCustomerResponseBody2TypedDict,
        CreateCustomerResponseTypedDict,
    )
    from .createdisputerequest import (
        CreateDisputeRequest,
        CreateDisputeRequestTypedDict,
    )
    from .createentitlementgrantop import (
        CreateEntitlementGrantRequest,
        CreateEntitlementGrantRequestTypedDict,
    )
    from .createentitlementrequest import (
        CreateEntitlementRequest,
        CreateEntitlementRequestTypedDict,
        EntitlementDatum,
        EntitlementDatumTypedDict,
    )
    from .createfeatureop import (
        CreateFeatureRequest,
        CreateFeatureRequestTypedDict,
        CreateFeatureType,
    )
    from .createfeeop import CreateFeeRequest, CreateFeeRequestTypedDict
    from .creategrantrequest import CreateGrantRequest, CreateGrantRequestTypedDict
    from .createlineitemop import CreateLineItemRequest, CreateLineItemRequestTypedDict
    from .createmanuallineitemrequest import (
        CreateManualLineItemRequest,
        CreateManualLineItemRequestTypedDict,
    )
    from .createpaymentop import (
        CreatePaymentLineItem,
        CreatePaymentLineItemTypedDict,
        CreatePaymentRequest,
        CreatePaymentRequestTypedDict,
        Currency,
    )
    from .createplanop import (
        BillingVersion,
        CreatePlanRequest,
        CreatePlanRequestTypedDict,
        CreatePlanTaxBehavior,
    )
    from .createpriceop import (
        CreatePriceModel,
        CreatePricePaymentTerm,
        CreatePriceRequest,
        CreatePriceRequestTypedDict,
    )
    from .createproductop import (
        CreateProductRequest,
        CreateProductRequestTypedDict,
        Metadata,
        MetadataTypedDict,
    )
    from .createrulerequest import CreateRuleRequest, CreateRuleRequestTypedDict
    from .createsourceop import (
        CreateSourceProcessingMode,
        CreateSourceRequest,
        CreateSourceRequestTypedDict,
        CreateSourceType,
    )
    from .createsubscriptionop import (
        CreateSubscriptionAddress,
        CreateSubscriptionAddressTypedDict,
        CreateSubscriptionCustomer,
        CreateSubscriptionCustomerTypedDict,
        CreateSubscriptionRequest,
        CreateSubscriptionRequestTypedDict,
        RedirectUrls,
        RedirectUrlsTypedDict,
    )
    from .createtestclockop import (
        CreateTestClockRequest,
        CreateTestClockRequestTypedDict,
    )
    from .createusageeventrequest import (
        CreateUsageEventRequest,
        CreateUsageEventRequestProperty,
        CreateUsageEventRequestPropertyTypedDict,
        CreateUsageEventRequestTypedDict,
    )
    from .customer import (
        Customer,
        CustomerObject,
        CustomerOrganization,
        CustomerOrganizationTypedDict,
        CustomerTypedDict,
    )
    from .deletecustomerop import (
        DeleteCustomerBlocker,
        DeleteCustomerBlockerTypedDict,
        DeleteCustomerDetails,
        DeleteCustomerDetailsTypedDict,
        DeleteCustomerError,
        DeleteCustomerRequest,
        DeleteCustomerRequestTypedDict,
        DeleteCustomerType,
        Item,
        ItemTypedDict,
    )
    from .deletefeatureop import DeleteFeatureRequest, DeleteFeatureRequestTypedDict
    from .deletefeeop import (
        DeleteFeeBlocker,
        DeleteFeeBlockerTypedDict,
        DeleteFeeDetails,
        DeleteFeeDetailsTypedDict,
        DeleteFeeRequest,
        DeleteFeeRequestTypedDict,
    )
    from .deletepriceop import DeletePriceRequest, DeletePriceRequestTypedDict
    from .deletesourceruleop import (
        DeleteSourceRuleRequest,
        DeleteSourceRuleRequestTypedDict,
    )
    from .deletetestclockop import (
        DeleteTestClockRequest,
        DeleteTestClockRequestTypedDict,
    )
    from .dispute import Dispute, DisputeObject, DisputeStatus, DisputeTypedDict
    from .disputewithcustomer import (
        DisputeWithCustomer,
        DisputeWithCustomerCustomer,
        DisputeWithCustomerCustomerTypedDict,
        DisputeWithCustomerObject,
        DisputeWithCustomerStatus,
        DisputeWithCustomerTypedDict,
    )
    from .entitlement import (
        Entitlement,
        EntitlementBillableMetric,
        EntitlementBillableMetricTypedDict,
        EntitlementObject,
        EntitlementTypedDict,
    )
    from .entitlementaccessresult import (
        EntitlementAccessResult,
        EntitlementAccessResultStatus,
        EntitlementAccessResultTypedDict,
        FeatureTypeEnum,
    )
    from .entitlementdetail import (
        EntitlementDetail,
        EntitlementDetailTypedDict,
        UnknownEntitlementDetail,
    )
    from .entitlementtemplate import (
        EntitlementTemplate,
        EntitlementTemplateBoolean,
        EntitlementTemplateBooleanTypedDict,
        EntitlementTemplateMetered,
        EntitlementTemplateMeteredTypedDict,
        EntitlementTemplateStatic,
        EntitlementTemplateStaticTypedDict,
        EntitlementTemplateTypedDict,
        UsagePeriod,
        UsagePeriodTypedDict,
    )
    from .eventresponse import (
        EventResponse,
        EventResponseObject,
        EventResponseTypedDict,
    )
    from .feature import Feature, FeatureObject, FeatureType, FeatureTypedDict
    from .fee import Fee, FeeObject, FeeTypedDict
    from .feeprice import (
        FeePrice,
        FeePriceModel,
        FeePricePaymentTerm,
        FeePriceTypedDict,
        Properties,
        PropertiesTypedDict,
    )
    from .generateportallinkop import (
        GeneratePortalLinkRequest,
        GeneratePortalLinkRequestBody,
        GeneratePortalLinkRequestBodyTypedDict,
        GeneratePortalLinkRequestTypedDict,
    )
    from .getactiveentitlementsop import (
        GetActiveEntitlementsObject,
        GetActiveEntitlementsPagination,
        GetActiveEntitlementsPaginationTypedDict,
        GetActiveEntitlementsRequest,
        GetActiveEntitlementsRequestTypedDict,
        GetActiveEntitlementsResponse,
        GetActiveEntitlementsResponseTypedDict,
    )
    from .getbillablemetricmeterop import (
        GetBillableMetricMeterRequest,
        GetBillableMetricMeterRequestTypedDict,
        WindowSize,
    )
    from .getbillablemetricop import (
        GetBillableMetricRequest,
        GetBillableMetricRequestTypedDict,
    )
    from .getcustomerop import GetCustomerRequest, GetCustomerRequestTypedDict
    from .getentitlementgrantop import (
        GetEntitlementGrantRequest,
        GetEntitlementGrantRequestTypedDict,
    )
    from .getentitlementop import GetEntitlementRequest, GetEntitlementRequestTypedDict
    from .getfeatureop import GetFeatureRequest, GetFeatureRequestTypedDict
    from .getfeeop import GetFeeRequest, GetFeeRequestTypedDict
    from .getfeepriceop import GetFeePriceRequest, GetFeePriceRequestTypedDict
    from .getinvoicelineitemsop import (
        GetInvoiceLineItemsRequest,
        GetInvoiceLineItemsRequestTypedDict,
    )
    from .getinvoiceop import GetInvoiceRequest, GetInvoiceRequestTypedDict
    from .getpaymentop import GetPaymentRequest, GetPaymentRequestTypedDict
    from .getplanop import GetPlanRequest, GetPlanRequestTypedDict
    from .getpriceop import GetPriceRequest, GetPriceRequestTypedDict
    from .getproductop import GetProductRequest, GetProductRequestTypedDict
    from .getrevenueop import (
        BucketWidth,
        GetRevenueRequest,
        GetRevenueRequestTypedDict,
        GroupBy,
    )
    from .getsourceop import GetSourceRequest, GetSourceRequestTypedDict
    from .getsourceruleop import GetSourceRuleRequest, GetSourceRuleRequestTypedDict
    from .getsubscriptionop import (
        GetSubscriptionRequest,
        GetSubscriptionRequestTypedDict,
    )
    from .gettestclockop import GetTestClockRequest, GetTestClockRequestTypedDict
    from .getusageeventop import GetUsageEventRequest, GetUsageEventRequestTypedDict
    from .getuserop import GetUserRequest, GetUserRequestTypedDict
    from .grant import Grant, GrantObject, GrantTypedDict
    from .groupinvoicesummary import GroupInvoiceSummary, GroupInvoiceSummaryTypedDict
    from .grouptrendentry import GroupTrendEntry, GroupTrendEntryTypedDict
    from .ingesteventop import IngestEventRequest, IngestEventRequestTypedDict
    from .invoice import (
        Invoice,
        InvoiceObject,
        InvoiceStatus,
        InvoiceTypedDict,
        LineItems,
        LineItemsTypedDict,
        Tax,
        TaxTypedDict,
    )
    from .invoicecategorysummary import (
        InvoiceCategorySummary,
        InvoiceCategorySummaryTypedDict,
    )
    from .invoicelineitem import (
        EventType,
        InvoiceLineItem,
        InvoiceLineItemLineItemType,
        InvoiceLineItemTypedDict,
    )
    from .invoicelineitemsresponse import (
        InvoiceLineItemsResponse,
        InvoiceLineItemsResponseTypedDict,
    )
    from .invoicesummary import InvoiceSummary, InvoiceSummaryTypedDict
    from .issueentitlementrequest import (
        IssueEntitlementRequest,
        IssueEntitlementRequestTypedDict,
    )
    from .lineitem import (
        LineItem,
        LineItemPaymentTerm,
        LineItemStatus,
        LineItemType,
        LineItemTypedDict,
    )
    from .lineitemsresponse import (
        LineItemsResponse,
        LineItemsResponseObject,
        LineItemsResponseTypedDict,
    )
    from .lineitemssummary import LineItemsSummary, LineItemsSummaryTypedDict
    from .listavailableplansop import (
        ListAvailablePlansPagination,
        ListAvailablePlansPaginationTypedDict,
        ListAvailablePlansRequest,
        ListAvailablePlansRequestTypedDict,
        ListAvailablePlansResponse,
        ListAvailablePlansResponseTypedDict,
    )
    from .listbillablemetricsop import (
        ListBillableMetricsObject,
        ListBillableMetricsPagination,
        ListBillableMetricsPaginationTypedDict,
        ListBillableMetricsRequest,
        ListBillableMetricsRequestTypedDict,
        ListBillableMetricsResponse,
        ListBillableMetricsResponseTypedDict,
    )
    from .listcustomersop import (
        ListCustomersObject,
        ListCustomersRequest,
        ListCustomersRequestTypedDict,
        ListCustomersResponse,
        ListCustomersResponseTypedDict,
    )
    from .listdisputesop import (
        ListDisputesObject,
        ListDisputesPagination,
        ListDisputesPaginationTypedDict,
        ListDisputesRequest,
        ListDisputesRequestTypedDict,
        ListDisputesResponse,
        ListDisputesResponseTypedDict,
        ListDisputesStatus,
    )
    from .listentitlementgrantsop import (
        ListEntitlementGrantsObject,
        ListEntitlementGrantsRequest,
        ListEntitlementGrantsRequestTypedDict,
        ListEntitlementGrantsResponse,
        ListEntitlementGrantsResponseTypedDict,
    )
    from .listentitlementsop import (
        ListEntitlementsObject,
        ListEntitlementsRequest,
        ListEntitlementsRequestTypedDict,
        ListEntitlementsResponse,
        ListEntitlementsResponseTypedDict,
    )
    from .listfeaturesop import (
        ListFeaturesObject,
        ListFeaturesPagination,
        ListFeaturesPaginationTypedDict,
        ListFeaturesRequest,
        ListFeaturesRequestTypedDict,
        ListFeaturesResponse,
        ListFeaturesResponseTypedDict,
    )
    from .listfeesop import (
        ListFeesObject,
        ListFeesPagination,
        ListFeesPaginationTypedDict,
        ListFeesRequest,
        ListFeesRequestTypedDict,
        ListFeesResponse,
        ListFeesResponseTypedDict,
    )
    from .listinvoicesop import (
        ListInvoicesObject,
        ListInvoicesRequest,
        ListInvoicesRequestTypedDict,
        ListInvoicesResponse,
        ListInvoicesResponseTypedDict,
        ListInvoicesStatus,
        NextActionAt,
    )
    from .listlineitemsop import (
        ListLineItemsRequest,
        ListLineItemsRequestTypedDict,
        ListLineItemsStatus,
    )
    from .listpaymentsop import (
        ListPaymentsObject,
        ListPaymentsRequest,
        ListPaymentsRequestTypedDict,
        ListPaymentsResponse,
        ListPaymentsResponseTypedDict,
        ListPaymentsStatus,
    )
    from .listplansop import (
        ListPlansPagination,
        ListPlansPaginationTypedDict,
        ListPlansRequest,
        ListPlansRequestTypedDict,
        ListPlansResponse,
        ListPlansResponseTypedDict,
    )
    from .listpricesop import (
        ListPricesPagination,
        ListPricesPaginationTypedDict,
        ListPricesRequest,
        ListPricesRequestTypedDict,
        ListPricesResponse,
        ListPricesResponseTypedDict,
    )
    from .listproductsop import (
        ListProductsRequest,
        ListProductsRequestTypedDict,
        ListProductsResponse,
        ListProductsResponseTypedDict,
    )
    from .listsourceeventsop import (
        ListSourceEventsRequest,
        ListSourceEventsRequestTypedDict,
        ListSourceEventsResponse,
        ListSourceEventsResponseTypedDict,
        ListSourceEventsStatus,
    )
    from .listsourcerulesop import (
        ListSourceRulesRequest,
        ListSourceRulesRequestTypedDict,
        ListSourceRulesResponse,
        ListSourceRulesResponseTypedDict,
    )
    from .listsourcesop import (
        ListSourcesRequest,
        ListSourcesRequestTypedDict,
        ListSourcesResponse,
        ListSourcesResponseTypedDict,
    )
    from .listsubscriptionsop import (
        ListSubscriptionsRequest,
        ListSubscriptionsRequestTypedDict,
        ListSubscriptionsResponse,
        ListSubscriptionsResponseTypedDict,
        ListSubscriptionsStatus,
    )
    from .listtestclocksop import (
        ListTestClocksPagination,
        ListTestClocksPaginationTypedDict,
        ListTestClocksRequest,
        ListTestClocksRequestTypedDict,
        ListTestClocksResponse,
        ListTestClocksResponseTypedDict,
    )
    from .listusageeventsop import (
        ListUsageEventsObject,
        ListUsageEventsRequest,
        ListUsageEventsRequestTypedDict,
        ListUsageEventsResponse,
        ListUsageEventsResponseTypedDict,
    )
    from .meteredentitlementdetail import (
        MeteredEntitlementDetail,
        MeteredEntitlementDetailObject,
        MeteredEntitlementDetailStatus,
        MeteredEntitlementDetailTypedDict,
    )
    from .offsetpagination import OffsetPagination, OffsetPaginationTypedDict
    from .payment import (
        Payment,
        PaymentLineItem,
        PaymentLineItemTypedDict,
        PaymentObject,
        PaymentStatus,
        PaymentTypedDict,
    )
    from .paymentsummary import PaymentSummary, PaymentSummaryTypedDict
    from .plan import (
        Plan,
        PlanObject,
        PlanPaymentTerm,
        PlanPaymentTermTypedDict,
        PlanTypedDict,
        TaxBehavior,
    )
    from .price import Price, PriceModel, PriceObject, PricePaymentTerm, PriceTypedDict
    from .pricefeature import (
        PriceFeature,
        PriceFeatureFeature,
        PriceFeatureFeatureTypedDict,
        PriceFeatureType,
        PriceFeatureTypedDict,
    )
    from .pricefeatureinput import PriceFeatureInput, PriceFeatureInputTypedDict
    from .priceproperties_union import (
        Function,
        Parameters,
        ParametersTypedDict,
        PriceProperties1,
        PriceProperties1TypedDict,
        PriceProperties2,
        PriceProperties2TypedDict,
        PriceProperties3,
        PriceProperties3TypedDict,
        PriceProperties4,
        PriceProperties4TypedDict,
        PricePropertiesUnion,
        PricePropertiesUnionTypedDict,
    )
    from .product import Product, ProductObject, ProductTypedDict
    from .purchaseentitlementgrantop import (
        PurchaseEntitlementGrantRequest,
        PurchaseEntitlementGrantRequestTypedDict,
    )
    from .purchasegrantrequest import (
        PurchaseGrantRequest,
        PurchaseGrantRequestTypedDict,
    )
    from .purchasegrantresponse import (
        PaymentSession,
        PaymentSessionTypedDict,
        PurchaseGrantResponse,
        PurchaseGrantResponseObject,
        PurchaseGrantResponseTypedDict,
    )
    from .refundusageeventop import (
        RefundUsageEventRequest,
        RefundUsageEventRequestBody,
        RefundUsageEventRequestBodyTypedDict,
        RefundUsageEventRequestTypedDict,
    )
    from .rejectsourceeventop import (
        RejectSourceEventRequest,
        RejectSourceEventRequestTypedDict,
    )
    from .revenuesummaryresponse import (
        RevenueSummaryResponse,
        RevenueSummaryResponseTypedDict,
    )
    from .revenuetrendbucket import RevenueTrendBucket, RevenueTrendBucketTypedDict
    from .rulecondition import (
        From,
        FromTypedDict,
        Operator,
        RuleCondition,
        RuleConditionType,
        RuleConditionTypedDict,
        To,
        ToTypedDict,
        Value,
        ValueTypedDict,
        ValueUnion,
        ValueUnionTypedDict,
    )
    from .schemas_entitlement import (
        SchemasEntitlement,
        SchemasEntitlementObject,
        SchemasEntitlementStatus,
        SchemasEntitlementTypedDict,
    )
    from .schemas_price import (
        SchemasPrice,
        SchemasPriceModel,
        SchemasPriceObject,
        SchemasPricePaymentTerm,
        SchemasPriceTypedDict,
    )
    from .security import Security, SecurityTypedDict
    from .source import (
        ProcessingMode,
        Source,
        SourceObject,
        SourceType,
        SourceTypedDict,
    )
    from .sourceevent import SourceEvent, SourceEventStatus, SourceEventTypedDict
    from .sourcerule import SourceRule, SourceRuleTypedDict
    from .staticentitlementdetail import (
        StaticEntitlementDetail,
        StaticEntitlementDetailObject,
        StaticEntitlementDetailStatus,
        StaticEntitlementDetailTypedDict,
    )
    from .subscription import (
        Breakdown,
        BreakdownTypedDict,
        PaymentPaid,
        PaymentPaidTypedDict,
        PaymentPending,
        PaymentPendingTypedDict,
        PaymentUnion,
        PaymentUnionTypedDict,
        Subscription,
        SubscriptionObject,
        SubscriptionStatusEnum,
        SubscriptionTypedDict,
        UnknownPaymentUnion,
    )
    from .subscriptionportal import (
        SubscriptionPortal,
        SubscriptionPortalObject,
        SubscriptionPortalTypedDict,
    )
    from .terminatesubscriptionop import (
        TerminateSubscriptionRequest,
        TerminateSubscriptionRequestBody,
        TerminateSubscriptionRequestBodyTypedDict,
        TerminateSubscriptionRequestTypedDict,
    )
    from .testclock import TestClock, TestClockTypedDict
    from .updatebillablemetricop import (
        UpdateBillableMetricRequest,
        UpdateBillableMetricRequestBody,
        UpdateBillableMetricRequestBodyTypedDict,
        UpdateBillableMetricRequestTypedDict,
    )
    from .updatecustomerop import (
        TaxRates,
        TaxRatesTypedDict,
        UpdateCustomerRequest,
        UpdateCustomerRequestBody,
        UpdateCustomerRequestBodyTypedDict,
        UpdateCustomerRequestTypedDict,
    )
    from .updatefeatureop import (
        UpdateFeatureRequest,
        UpdateFeatureRequestBody,
        UpdateFeatureRequestBodyTypedDict,
        UpdateFeatureRequestTypedDict,
        UpdateFeatureType,
    )
    from .updatefeeop import (
        UpdateFeeRequest,
        UpdateFeeRequestBody,
        UpdateFeeRequestBodyTypedDict,
        UpdateFeeRequestTypedDict,
    )
    from .updateplanop import (
        UpdatePlanRequest,
        UpdatePlanRequestBody,
        UpdatePlanRequestBodyTypedDict,
        UpdatePlanRequestTypedDict,
        UpdatePlanTaxBehavior,
    )
    from .updatepriceop import (
        UpdatePriceModel,
        UpdatePricePaymentTerm,
        UpdatePriceRequest,
        UpdatePriceRequestBody,
        UpdatePriceRequestBodyTypedDict,
        UpdatePriceRequestTypedDict,
    )
    from .updateproductop import (
        UpdateProductRequest,
        UpdateProductRequestBody,
        UpdateProductRequestBodyTypedDict,
        UpdateProductRequestTypedDict,
    )
    from .updaterulerequest import UpdateRuleRequest, UpdateRuleRequestTypedDict
    from .updatesourceop import (
        UpdateSourceProcessingMode,
        UpdateSourceRequest,
        UpdateSourceRequestBody,
        UpdateSourceRequestBodyTypedDict,
        UpdateSourceRequestTypedDict,
    )
    from .updatesourceruleop import (
        UpdateSourceRuleRequest,
        UpdateSourceRuleRequestTypedDict,
    )
    from .updateuserop import (
        UpdateUserRequest,
        UpdateUserRequestBody,
        UpdateUserRequestBodyTypedDict,
        UpdateUserRequestTypedDict,
        UpdateUserType,
    )
    from .usageevent import (
        Billing,
        BillingTypedDict,
        Refund,
        RefundTypedDict,
        UsageEvent,
        UsageEventObject,
        UsageEventProperty,
        UsageEventPropertyTypedDict,
        UsageEventTypedDict,
    )
    from .usageresponse import (
        GroupedValue,
        GroupedValueTypedDict,
        UsageResponse,
        UsageResponseObject,
        UsageResponseTypedDict,
        WindowedValue,
        WindowedValueTypedDict,
    )
    from .user import (
        State,
        User,
        UserObject,
        UserOrganization,
        UserOrganizationTypedDict,
        UserType,
        UserTypedDict,
    )
    from .validationerror import Error, ErrorEnum, ErrorTypedDict
    from .validtaxaddress import ValidTaxAddress, ValidTaxAddressTypedDict
    from .voidentitlementgrantop import (
        VoidEntitlementGrantRequest,
        VoidEntitlementGrantRequestTypedDict,
    )

__all__ = [
    "ActiveEntitlement",
    "ActiveEntitlementObject",
    "ActiveEntitlementTypedDict",
    "Address",
    "AddressTypedDict",
    "AdvanceTestClockRequest",
    "AdvanceTestClockRequestBody",
    "AdvanceTestClockRequestBodyTypedDict",
    "AdvanceTestClockRequestTypedDict",
    "Aggregation",
    "ApproveSourceEventRequest",
    "ApproveSourceEventRequestTypedDict",
    "BatchCreateUsageEventsRequest",
    "BatchCreateUsageEventsRequestTypedDict",
    "BatchUsageEventResponse",
    "BatchUsageEventResponseObject",
    "BatchUsageEventResponseTypedDict",
    "BillableMetric",
    "BillableMetricObject",
    "BillableMetricTypedDict",
    "Billing",
    "BillingTypedDict",
    "BillingVersion",
    "BooleanEntitlementDetail",
    "BooleanEntitlementDetailObject",
    "BooleanEntitlementDetailStatus",
    "BooleanEntitlementDetailTypedDict",
    "Breakdown",
    "BreakdownTypedDict",
    "BucketWidth",
    "BulkApproveSourceEventsDetails",
    "BulkApproveSourceEventsDetailsTypedDict",
    "BulkApproveSourceEventsFailed",
    "BulkApproveSourceEventsFailedTypedDict",
    "BulkApproveSourceEventsRequest",
    "BulkApproveSourceEventsRequestBody",
    "BulkApproveSourceEventsRequestBodyTypedDict",
    "BulkApproveSourceEventsRequestTypedDict",
    "BulkApproveSourceEventsResponse",
    "BulkApproveSourceEventsResponseTypedDict",
    "BulkRejectSourceEventsRequest",
    "BulkRejectSourceEventsRequestBody",
    "BulkRejectSourceEventsRequestBodyTypedDict",
    "BulkRejectSourceEventsRequestTypedDict",
    "BulkRejectSourceEventsResponse",
    "BulkRejectSourceEventsResponseTypedDict",
    "Consumer",
    "ConsumerTypedDict",
    "CreateBillableMetricAggregation",
    "CreateBillableMetricRequest",
    "CreateBillableMetricRequestTypedDict",
    "CreateCustomerRequest",
    "CreateCustomerRequestTypedDict",
    "CreateCustomerResponse",
    "CreateCustomerResponseBody1",
    "CreateCustomerResponseBody1TypedDict",
    "CreateCustomerResponseBody2",
    "CreateCustomerResponseBody2TypedDict",
    "CreateCustomerResponseTypedDict",
    "CreateDisputeRequest",
    "CreateDisputeRequestTypedDict",
    "CreateEntitlementGrantRequest",
    "CreateEntitlementGrantRequestTypedDict",
    "CreateEntitlementRequest",
    "CreateEntitlementRequestTypedDict",
    "CreateFeatureRequest",
    "CreateFeatureRequestTypedDict",
    "CreateFeatureType",
    "CreateFeeRequest",
    "CreateFeeRequestTypedDict",
    "CreateGrantRequest",
    "CreateGrantRequestTypedDict",
    "CreateLineItemRequest",
    "CreateLineItemRequestTypedDict",
    "CreateManualLineItemRequest",
    "CreateManualLineItemRequestTypedDict",
    "CreatePaymentLineItem",
    "CreatePaymentLineItemTypedDict",
    "CreatePaymentRequest",
    "CreatePaymentRequestTypedDict",
    "CreatePlanRequest",
    "CreatePlanRequestTypedDict",
    "CreatePlanTaxBehavior",
    "CreatePriceModel",
    "CreatePricePaymentTerm",
    "CreatePriceRequest",
    "CreatePriceRequestTypedDict",
    "CreateProductRequest",
    "CreateProductRequestTypedDict",
    "CreateRuleRequest",
    "CreateRuleRequestTypedDict",
    "CreateSourceProcessingMode",
    "CreateSourceRequest",
    "CreateSourceRequestTypedDict",
    "CreateSourceType",
    "CreateSubscriptionAddress",
    "CreateSubscriptionAddressTypedDict",
    "CreateSubscriptionCustomer",
    "CreateSubscriptionCustomerTypedDict",
    "CreateSubscriptionRequest",
    "CreateSubscriptionRequestTypedDict",
    "CreateTestClockRequest",
    "CreateTestClockRequestTypedDict",
    "CreateUsageEventRequest",
    "CreateUsageEventRequestProperty",
    "CreateUsageEventRequestPropertyTypedDict",
    "CreateUsageEventRequestTypedDict",
    "Currency",
    "Customer",
    "CustomerObject",
    "CustomerOrganization",
    "CustomerOrganizationTypedDict",
    "CustomerTypedDict",
    "DeleteCustomerBlocker",
    "DeleteCustomerBlockerTypedDict",
    "DeleteCustomerDetails",
    "DeleteCustomerDetailsTypedDict",
    "DeleteCustomerError",
    "DeleteCustomerRequest",
    "DeleteCustomerRequestTypedDict",
    "DeleteCustomerType",
    "DeleteFeatureRequest",
    "DeleteFeatureRequestTypedDict",
    "DeleteFeeBlocker",
    "DeleteFeeBlockerTypedDict",
    "DeleteFeeDetails",
    "DeleteFeeDetailsTypedDict",
    "DeleteFeeRequest",
    "DeleteFeeRequestTypedDict",
    "DeletePriceRequest",
    "DeletePriceRequestTypedDict",
    "DeleteSourceRuleRequest",
    "DeleteSourceRuleRequestTypedDict",
    "DeleteTestClockRequest",
    "DeleteTestClockRequestTypedDict",
    "Dispute",
    "DisputeObject",
    "DisputeStatus",
    "DisputeTypedDict",
    "DisputeWithCustomer",
    "DisputeWithCustomerCustomer",
    "DisputeWithCustomerCustomerTypedDict",
    "DisputeWithCustomerObject",
    "DisputeWithCustomerStatus",
    "DisputeWithCustomerTypedDict",
    "Entitlement",
    "EntitlementAccessResult",
    "EntitlementAccessResultStatus",
    "EntitlementAccessResultTypedDict",
    "EntitlementBillableMetric",
    "EntitlementBillableMetricTypedDict",
    "EntitlementDatum",
    "EntitlementDatumTypedDict",
    "EntitlementDetail",
    "EntitlementDetailTypedDict",
    "EntitlementObject",
    "EntitlementTemplate",
    "EntitlementTemplateBoolean",
    "EntitlementTemplateBooleanTypedDict",
    "EntitlementTemplateMetered",
    "EntitlementTemplateMeteredTypedDict",
    "EntitlementTemplateStatic",
    "EntitlementTemplateStaticTypedDict",
    "EntitlementTemplateTypedDict",
    "EntitlementTypedDict",
    "Error",
    "ErrorEnum",
    "ErrorTypedDict",
    "EventResponse",
    "EventResponseObject",
    "EventResponseTypedDict",
    "EventType",
    "Failed",
    "FailedTypedDict",
    "Feature",
    "FeatureObject",
    "FeatureType",
    "FeatureTypeEnum",
    "FeatureTypedDict",
    "Fee",
    "FeeObject",
    "FeePrice",
    "FeePriceModel",
    "FeePricePaymentTerm",
    "FeePriceTypedDict",
    "FeeTypedDict",
    "From",
    "FromTypedDict",
    "Function",
    "GeneratePortalLinkRequest",
    "GeneratePortalLinkRequestBody",
    "GeneratePortalLinkRequestBodyTypedDict",
    "GeneratePortalLinkRequestTypedDict",
    "GetActiveEntitlementsObject",
    "GetActiveEntitlementsPagination",
    "GetActiveEntitlementsPaginationTypedDict",
    "GetActiveEntitlementsRequest",
    "GetActiveEntitlementsRequestTypedDict",
    "GetActiveEntitlementsResponse",
    "GetActiveEntitlementsResponseTypedDict",
    "GetBillableMetricMeterRequest",
    "GetBillableMetricMeterRequestTypedDict",
    "GetBillableMetricRequest",
    "GetBillableMetricRequestTypedDict",
    "GetCustomerRequest",
    "GetCustomerRequestTypedDict",
    "GetEntitlementGrantRequest",
    "GetEntitlementGrantRequestTypedDict",
    "GetEntitlementRequest",
    "GetEntitlementRequestTypedDict",
    "GetFeatureRequest",
    "GetFeatureRequestTypedDict",
    "GetFeePriceRequest",
    "GetFeePriceRequestTypedDict",
    "GetFeeRequest",
    "GetFeeRequestTypedDict",
    "GetInvoiceLineItemsRequest",
    "GetInvoiceLineItemsRequestTypedDict",
    "GetInvoiceRequest",
    "GetInvoiceRequestTypedDict",
    "GetPaymentRequest",
    "GetPaymentRequestTypedDict",
    "GetPlanRequest",
    "GetPlanRequestTypedDict",
    "GetPriceRequest",
    "GetPriceRequestTypedDict",
    "GetProductRequest",
    "GetProductRequestTypedDict",
    "GetRevenueRequest",
    "GetRevenueRequestTypedDict",
    "GetSourceRequest",
    "GetSourceRequestTypedDict",
    "GetSourceRuleRequest",
    "GetSourceRuleRequestTypedDict",
    "GetSubscriptionRequest",
    "GetSubscriptionRequestTypedDict",
    "GetTestClockRequest",
    "GetTestClockRequestTypedDict",
    "GetUsageEventRequest",
    "GetUsageEventRequestTypedDict",
    "GetUserRequest",
    "GetUserRequestTypedDict",
    "Grant",
    "GrantObject",
    "GrantTypedDict",
    "GroupBy",
    "GroupInvoiceSummary",
    "GroupInvoiceSummaryTypedDict",
    "GroupTrendEntry",
    "GroupTrendEntryTypedDict",
    "GroupedValue",
    "GroupedValueTypedDict",
    "IngestEventRequest",
    "IngestEventRequestTypedDict",
    "Invoice",
    "InvoiceCategorySummary",
    "InvoiceCategorySummaryTypedDict",
    "InvoiceLineItem",
    "InvoiceLineItemLineItemType",
    "InvoiceLineItemTypedDict",
    "InvoiceLineItemsResponse",
    "InvoiceLineItemsResponseTypedDict",
    "InvoiceObject",
    "InvoiceStatus",
    "InvoiceSummary",
    "InvoiceSummaryTypedDict",
    "InvoiceTypedDict",
    "IssueEntitlementRequest",
    "IssueEntitlementRequestTypedDict",
    "Item",
    "ItemTypedDict",
    "LineItem",
    "LineItemPaymentTerm",
    "LineItemStatus",
    "LineItemType",
    "LineItemTypedDict",
    "LineItems",
    "LineItemsResponse",
    "LineItemsResponseObject",
    "LineItemsResponseTypedDict",
    "LineItemsSummary",
    "LineItemsSummaryTypedDict",
    "LineItemsTypedDict",
    "ListAvailablePlansPagination",
    "ListAvailablePlansPaginationTypedDict",
    "ListAvailablePlansRequest",
    "ListAvailablePlansRequestTypedDict",
    "ListAvailablePlansResponse",
    "ListAvailablePlansResponseTypedDict",
    "ListBillableMetricsObject",
    "ListBillableMetricsPagination",
    "ListBillableMetricsPaginationTypedDict",
    "ListBillableMetricsRequest",
    "ListBillableMetricsRequestTypedDict",
    "ListBillableMetricsResponse",
    "ListBillableMetricsResponseTypedDict",
    "ListCustomersObject",
    "ListCustomersRequest",
    "ListCustomersRequestTypedDict",
    "ListCustomersResponse",
    "ListCustomersResponseTypedDict",
    "ListDisputesObject",
    "ListDisputesPagination",
    "ListDisputesPaginationTypedDict",
    "ListDisputesRequest",
    "ListDisputesRequestTypedDict",
    "ListDisputesResponse",
    "ListDisputesResponseTypedDict",
    "ListDisputesStatus",
    "ListEntitlementGrantsObject",
    "ListEntitlementGrantsRequest",
    "ListEntitlementGrantsRequestTypedDict",
    "ListEntitlementGrantsResponse",
    "ListEntitlementGrantsResponseTypedDict",
    "ListEntitlementsObject",
    "ListEntitlementsRequest",
    "ListEntitlementsRequestTypedDict",
    "ListEntitlementsResponse",
    "ListEntitlementsResponseTypedDict",
    "ListFeaturesObject",
    "ListFeaturesPagination",
    "ListFeaturesPaginationTypedDict",
    "ListFeaturesRequest",
    "ListFeaturesRequestTypedDict",
    "ListFeaturesResponse",
    "ListFeaturesResponseTypedDict",
    "ListFeesObject",
    "ListFeesPagination",
    "ListFeesPaginationTypedDict",
    "ListFeesRequest",
    "ListFeesRequestTypedDict",
    "ListFeesResponse",
    "ListFeesResponseTypedDict",
    "ListInvoicesObject",
    "ListInvoicesRequest",
    "ListInvoicesRequestTypedDict",
    "ListInvoicesResponse",
    "ListInvoicesResponseTypedDict",
    "ListInvoicesStatus",
    "ListLineItemsRequest",
    "ListLineItemsRequestTypedDict",
    "ListLineItemsStatus",
    "ListPaymentsObject",
    "ListPaymentsRequest",
    "ListPaymentsRequestTypedDict",
    "ListPaymentsResponse",
    "ListPaymentsResponseTypedDict",
    "ListPaymentsStatus",
    "ListPlansPagination",
    "ListPlansPaginationTypedDict",
    "ListPlansRequest",
    "ListPlansRequestTypedDict",
    "ListPlansResponse",
    "ListPlansResponseTypedDict",
    "ListPricesPagination",
    "ListPricesPaginationTypedDict",
    "ListPricesRequest",
    "ListPricesRequestTypedDict",
    "ListPricesResponse",
    "ListPricesResponseTypedDict",
    "ListProductsRequest",
    "ListProductsRequestTypedDict",
    "ListProductsResponse",
    "ListProductsResponseTypedDict",
    "ListSourceEventsRequest",
    "ListSourceEventsRequestTypedDict",
    "ListSourceEventsResponse",
    "ListSourceEventsResponseTypedDict",
    "ListSourceEventsStatus",
    "ListSourceRulesRequest",
    "ListSourceRulesRequestTypedDict",
    "ListSourceRulesResponse",
    "ListSourceRulesResponseTypedDict",
    "ListSourcesRequest",
    "ListSourcesRequestTypedDict",
    "ListSourcesResponse",
    "ListSourcesResponseTypedDict",
    "ListSubscriptionsRequest",
    "ListSubscriptionsRequestTypedDict",
    "ListSubscriptionsResponse",
    "ListSubscriptionsResponseTypedDict",
    "ListSubscriptionsStatus",
    "ListTestClocksPagination",
    "ListTestClocksPaginationTypedDict",
    "ListTestClocksRequest",
    "ListTestClocksRequestTypedDict",
    "ListTestClocksResponse",
    "ListTestClocksResponseTypedDict",
    "ListUsageEventsObject",
    "ListUsageEventsRequest",
    "ListUsageEventsRequestTypedDict",
    "ListUsageEventsResponse",
    "ListUsageEventsResponseTypedDict",
    "Metadata",
    "MetadataTypedDict",
    "MeteredEntitlementDetail",
    "MeteredEntitlementDetailObject",
    "MeteredEntitlementDetailStatus",
    "MeteredEntitlementDetailTypedDict",
    "NextActionAt",
    "OffsetPagination",
    "OffsetPaginationTypedDict",
    "Operator",
    "Parameters",
    "ParametersTypedDict",
    "Payment",
    "PaymentLineItem",
    "PaymentLineItemTypedDict",
    "PaymentObject",
    "PaymentPaid",
    "PaymentPaidTypedDict",
    "PaymentPending",
    "PaymentPendingTypedDict",
    "PaymentSession",
    "PaymentSessionTypedDict",
    "PaymentStatus",
    "PaymentSummary",
    "PaymentSummaryTypedDict",
    "PaymentTypedDict",
    "PaymentUnion",
    "PaymentUnionTypedDict",
    "Plan",
    "PlanObject",
    "PlanPaymentTerm",
    "PlanPaymentTermTypedDict",
    "PlanTypedDict",
    "Price",
    "PriceFeature",
    "PriceFeatureFeature",
    "PriceFeatureFeatureTypedDict",
    "PriceFeatureInput",
    "PriceFeatureInputTypedDict",
    "PriceFeatureType",
    "PriceFeatureTypedDict",
    "PriceModel",
    "PriceObject",
    "PricePaymentTerm",
    "PriceProperties1",
    "PriceProperties1TypedDict",
    "PriceProperties2",
    "PriceProperties2TypedDict",
    "PriceProperties3",
    "PriceProperties3TypedDict",
    "PriceProperties4",
    "PriceProperties4TypedDict",
    "PricePropertiesUnion",
    "PricePropertiesUnionTypedDict",
    "PriceTypedDict",
    "ProcessingMode",
    "Product",
    "ProductObject",
    "ProductTypedDict",
    "Properties",
    "PropertiesTypedDict",
    "PurchaseEntitlementGrantRequest",
    "PurchaseEntitlementGrantRequestTypedDict",
    "PurchaseGrantRequest",
    "PurchaseGrantRequestTypedDict",
    "PurchaseGrantResponse",
    "PurchaseGrantResponseObject",
    "PurchaseGrantResponseTypedDict",
    "RedirectUrls",
    "RedirectUrlsTypedDict",
    "Refund",
    "RefundTypedDict",
    "RefundUsageEventRequest",
    "RefundUsageEventRequestBody",
    "RefundUsageEventRequestBodyTypedDict",
    "RefundUsageEventRequestTypedDict",
    "RejectSourceEventRequest",
    "RejectSourceEventRequestTypedDict",
    "RequestBody1",
    "RequestBody1TypedDict",
    "RequestBody2",
    "RequestBody2TypedDict",
    "RevenueSummaryResponse",
    "RevenueSummaryResponseTypedDict",
    "RevenueTrendBucket",
    "RevenueTrendBucketTypedDict",
    "RuleCondition",
    "RuleConditionType",
    "RuleConditionTypedDict",
    "SchemasEntitlement",
    "SchemasEntitlementObject",
    "SchemasEntitlementStatus",
    "SchemasEntitlementTypedDict",
    "SchemasPrice",
    "SchemasPriceModel",
    "SchemasPriceObject",
    "SchemasPricePaymentTerm",
    "SchemasPriceTypedDict",
    "Security",
    "SecurityTypedDict",
    "Source",
    "SourceEvent",
    "SourceEventStatus",
    "SourceEventTypedDict",
    "SourceObject",
    "SourceRule",
    "SourceRuleTypedDict",
    "SourceType",
    "SourceTypedDict",
    "State",
    "StaticEntitlementDetail",
    "StaticEntitlementDetailObject",
    "StaticEntitlementDetailStatus",
    "StaticEntitlementDetailTypedDict",
    "Subscription",
    "SubscriptionObject",
    "SubscriptionPortal",
    "SubscriptionPortalObject",
    "SubscriptionPortalTypedDict",
    "SubscriptionStatusEnum",
    "SubscriptionTypedDict",
    "Summary",
    "SummaryTypedDict",
    "Tax",
    "TaxBehavior",
    "TaxRates",
    "TaxRatesTypedDict",
    "TaxTypedDict",
    "TerminateSubscriptionRequest",
    "TerminateSubscriptionRequestBody",
    "TerminateSubscriptionRequestBodyTypedDict",
    "TerminateSubscriptionRequestTypedDict",
    "TestClock",
    "TestClockTypedDict",
    "To",
    "ToTypedDict",
    "UnknownEntitlementDetail",
    "UnknownPaymentUnion",
    "UpdateBillableMetricRequest",
    "UpdateBillableMetricRequestBody",
    "UpdateBillableMetricRequestBodyTypedDict",
    "UpdateBillableMetricRequestTypedDict",
    "UpdateCustomerRequest",
    "UpdateCustomerRequestBody",
    "UpdateCustomerRequestBodyTypedDict",
    "UpdateCustomerRequestTypedDict",
    "UpdateFeatureRequest",
    "UpdateFeatureRequestBody",
    "UpdateFeatureRequestBodyTypedDict",
    "UpdateFeatureRequestTypedDict",
    "UpdateFeatureType",
    "UpdateFeeRequest",
    "UpdateFeeRequestBody",
    "UpdateFeeRequestBodyTypedDict",
    "UpdateFeeRequestTypedDict",
    "UpdatePlanRequest",
    "UpdatePlanRequestBody",
    "UpdatePlanRequestBodyTypedDict",
    "UpdatePlanRequestTypedDict",
    "UpdatePlanTaxBehavior",
    "UpdatePriceModel",
    "UpdatePricePaymentTerm",
    "UpdatePriceRequest",
    "UpdatePriceRequestBody",
    "UpdatePriceRequestBodyTypedDict",
    "UpdatePriceRequestTypedDict",
    "UpdateProductRequest",
    "UpdateProductRequestBody",
    "UpdateProductRequestBodyTypedDict",
    "UpdateProductRequestTypedDict",
    "UpdateRuleRequest",
    "UpdateRuleRequestTypedDict",
    "UpdateSourceProcessingMode",
    "UpdateSourceRequest",
    "UpdateSourceRequestBody",
    "UpdateSourceRequestBodyTypedDict",
    "UpdateSourceRequestTypedDict",
    "UpdateSourceRuleRequest",
    "UpdateSourceRuleRequestTypedDict",
    "UpdateUserRequest",
    "UpdateUserRequestBody",
    "UpdateUserRequestBodyTypedDict",
    "UpdateUserRequestTypedDict",
    "UpdateUserType",
    "UsageEvent",
    "UsageEventObject",
    "UsageEventProperty",
    "UsageEventPropertyTypedDict",
    "UsageEventTypedDict",
    "UsagePeriod",
    "UsagePeriodTypedDict",
    "UsageResponse",
    "UsageResponseObject",
    "UsageResponseTypedDict",
    "User",
    "UserObject",
    "UserOrganization",
    "UserOrganizationTypedDict",
    "UserType",
    "UserTypedDict",
    "ValidTaxAddress",
    "ValidTaxAddressTypedDict",
    "Value",
    "ValueTypedDict",
    "ValueUnion",
    "ValueUnionTypedDict",
    "VoidEntitlementGrantRequest",
    "VoidEntitlementGrantRequestTypedDict",
    "WindowSize",
    "WindowedValue",
    "WindowedValueTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "ActiveEntitlement": ".activeentitlement",
    "ActiveEntitlementObject": ".activeentitlement",
    "ActiveEntitlementTypedDict": ".activeentitlement",
    "Address": ".address",
    "AddressTypedDict": ".address",
    "AdvanceTestClockRequest": ".advancetestclockop",
    "AdvanceTestClockRequestBody": ".advancetestclockop",
    "AdvanceTestClockRequestBodyTypedDict": ".advancetestclockop",
    "AdvanceTestClockRequestTypedDict": ".advancetestclockop",
    "RequestBody1": ".advancetestclockop",
    "RequestBody1TypedDict": ".advancetestclockop",
    "RequestBody2": ".advancetestclockop",
    "RequestBody2TypedDict": ".advancetestclockop",
    "ApproveSourceEventRequest": ".approvesourceeventop",
    "ApproveSourceEventRequestTypedDict": ".approvesourceeventop",
    "BatchCreateUsageEventsRequest": ".batchcreateusageeventsop",
    "BatchCreateUsageEventsRequestTypedDict": ".batchcreateusageeventsop",
    "BatchUsageEventResponse": ".batchusageeventresponse",
    "BatchUsageEventResponseObject": ".batchusageeventresponse",
    "BatchUsageEventResponseTypedDict": ".batchusageeventresponse",
    "Failed": ".batchusageeventresponse",
    "FailedTypedDict": ".batchusageeventresponse",
    "Summary": ".batchusageeventresponse",
    "SummaryTypedDict": ".batchusageeventresponse",
    "Aggregation": ".billablemetric",
    "BillableMetric": ".billablemetric",
    "BillableMetricObject": ".billablemetric",
    "BillableMetricTypedDict": ".billablemetric",
    "BooleanEntitlementDetail": ".booleanentitlementdetail",
    "BooleanEntitlementDetailObject": ".booleanentitlementdetail",
    "BooleanEntitlementDetailStatus": ".booleanentitlementdetail",
    "BooleanEntitlementDetailTypedDict": ".booleanentitlementdetail",
    "BulkApproveSourceEventsDetails": ".bulkapprovesourceeventsop",
    "BulkApproveSourceEventsDetailsTypedDict": ".bulkapprovesourceeventsop",
    "BulkApproveSourceEventsFailed": ".bulkapprovesourceeventsop",
    "BulkApproveSourceEventsFailedTypedDict": ".bulkapprovesourceeventsop",
    "BulkApproveSourceEventsRequest": ".bulkapprovesourceeventsop",
    "BulkApproveSourceEventsRequestBody": ".bulkapprovesourceeventsop",
    "BulkApproveSourceEventsRequestBodyTypedDict": ".bulkapprovesourceeventsop",
    "BulkApproveSourceEventsRequestTypedDict": ".bulkapprovesourceeventsop",
    "BulkApproveSourceEventsResponse": ".bulkapprovesourceeventsop",
    "BulkApproveSourceEventsResponseTypedDict": ".bulkapprovesourceeventsop",
    "BulkRejectSourceEventsRequest": ".bulkrejectsourceeventsop",
    "BulkRejectSourceEventsRequestBody": ".bulkrejectsourceeventsop",
    "BulkRejectSourceEventsRequestBodyTypedDict": ".bulkrejectsourceeventsop",
    "BulkRejectSourceEventsRequestTypedDict": ".bulkrejectsourceeventsop",
    "BulkRejectSourceEventsResponse": ".bulkrejectsourceeventsop",
    "BulkRejectSourceEventsResponseTypedDict": ".bulkrejectsourceeventsop",
    "CreateBillableMetricAggregation": ".createbillablemetricop",
    "CreateBillableMetricRequest": ".createbillablemetricop",
    "CreateBillableMetricRequestTypedDict": ".createbillablemetricop",
    "Consumer": ".createcustomerop",
    "ConsumerTypedDict": ".createcustomerop",
    "CreateCustomerRequest": ".createcustomerop",
    "CreateCustomerRequestTypedDict": ".createcustomerop",
    "CreateCustomerResponse": ".createcustomerop",
    "CreateCustomerResponseBody1": ".createcustomerop",
    "CreateCustomerResponseBody1TypedDict": ".createcustomerop",
    "CreateCustomerResponseBody2": ".createcustomerop",
    "CreateCustomerResponseBody2TypedDict": ".createcustomerop",
    "CreateCustomerResponseTypedDict": ".createcustomerop",
    "CreateDisputeRequest": ".createdisputerequest",
    "CreateDisputeRequestTypedDict": ".createdisputerequest",
    "CreateEntitlementGrantRequest": ".createentitlementgrantop",
    "CreateEntitlementGrantRequestTypedDict": ".createentitlementgrantop",
    "CreateEntitlementRequest": ".createentitlementrequest",
    "CreateEntitlementRequestTypedDict": ".createentitlementrequest",
    "EntitlementDatum": ".createentitlementrequest",
    "EntitlementDatumTypedDict": ".createentitlementrequest",
    "CreateFeatureRequest": ".createfeatureop",
    "CreateFeatureRequestTypedDict": ".createfeatureop",
    "CreateFeatureType": ".createfeatureop",
    "CreateFeeRequest": ".createfeeop",
    "CreateFeeRequestTypedDict": ".createfeeop",
    "CreateGrantRequest": ".creategrantrequest",
    "CreateGrantRequestTypedDict": ".creategrantrequest",
    "CreateLineItemRequest": ".createlineitemop",
    "CreateLineItemRequestTypedDict": ".createlineitemop",
    "CreateManualLineItemRequest": ".createmanuallineitemrequest",
    "CreateManualLineItemRequestTypedDict": ".createmanuallineitemrequest",
    "CreatePaymentLineItem": ".createpaymentop",
    "CreatePaymentLineItemTypedDict": ".createpaymentop",
    "CreatePaymentRequest": ".createpaymentop",
    "CreatePaymentRequestTypedDict": ".createpaymentop",
    "Currency": ".createpaymentop",
    "BillingVersion": ".createplanop",
    "CreatePlanRequest": ".createplanop",
    "CreatePlanRequestTypedDict": ".createplanop",
    "CreatePlanTaxBehavior": ".createplanop",
    "CreatePriceModel": ".createpriceop",
    "CreatePricePaymentTerm": ".createpriceop",
    "CreatePriceRequest": ".createpriceop",
    "CreatePriceRequestTypedDict": ".createpriceop",
    "CreateProductRequest": ".createproductop",
    "CreateProductRequestTypedDict": ".createproductop",
    "Metadata": ".createproductop",
    "MetadataTypedDict": ".createproductop",
    "CreateRuleRequest": ".createrulerequest",
    "CreateRuleRequestTypedDict": ".createrulerequest",
    "CreateSourceProcessingMode": ".createsourceop",
    "CreateSourceRequest": ".createsourceop",
    "CreateSourceRequestTypedDict": ".createsourceop",
    "CreateSourceType": ".createsourceop",
    "CreateSubscriptionAddress": ".createsubscriptionop",
    "CreateSubscriptionAddressTypedDict": ".createsubscriptionop",
    "CreateSubscriptionCustomer": ".createsubscriptionop",
    "CreateSubscriptionCustomerTypedDict": ".createsubscriptionop",
    "CreateSubscriptionRequest": ".createsubscriptionop",
    "CreateSubscriptionRequestTypedDict": ".createsubscriptionop",
    "RedirectUrls": ".createsubscriptionop",
    "RedirectUrlsTypedDict": ".createsubscriptionop",
    "CreateTestClockRequest": ".createtestclockop",
    "CreateTestClockRequestTypedDict": ".createtestclockop",
    "CreateUsageEventRequest": ".createusageeventrequest",
    "CreateUsageEventRequestProperty": ".createusageeventrequest",
    "CreateUsageEventRequestPropertyTypedDict": ".createusageeventrequest",
    "CreateUsageEventRequestTypedDict": ".createusageeventrequest",
    "Customer": ".customer",
    "CustomerObject": ".customer",
    "CustomerOrganization": ".customer",
    "CustomerOrganizationTypedDict": ".customer",
    "CustomerTypedDict": ".customer",
    "DeleteCustomerBlocker": ".deletecustomerop",
    "DeleteCustomerBlockerTypedDict": ".deletecustomerop",
    "DeleteCustomerDetails": ".deletecustomerop",
    "DeleteCustomerDetailsTypedDict": ".deletecustomerop",
    "DeleteCustomerError": ".deletecustomerop",
    "DeleteCustomerRequest": ".deletecustomerop",
    "DeleteCustomerRequestTypedDict": ".deletecustomerop",
    "DeleteCustomerType": ".deletecustomerop",
    "Item": ".deletecustomerop",
    "ItemTypedDict": ".deletecustomerop",
    "DeleteFeatureRequest": ".deletefeatureop",
    "DeleteFeatureRequestTypedDict": ".deletefeatureop",
    "DeleteFeeBlocker": ".deletefeeop",
    "DeleteFeeBlockerTypedDict": ".deletefeeop",
    "DeleteFeeDetails": ".deletefeeop",
    "DeleteFeeDetailsTypedDict": ".deletefeeop",
    "DeleteFeeRequest": ".deletefeeop",
    "DeleteFeeRequestTypedDict": ".deletefeeop",
    "DeletePriceRequest": ".deletepriceop",
    "DeletePriceRequestTypedDict": ".deletepriceop",
    "DeleteSourceRuleRequest": ".deletesourceruleop",
    "DeleteSourceRuleRequestTypedDict": ".deletesourceruleop",
    "DeleteTestClockRequest": ".deletetestclockop",
    "DeleteTestClockRequestTypedDict": ".deletetestclockop",
    "Dispute": ".dispute",
    "DisputeObject": ".dispute",
    "DisputeStatus": ".dispute",
    "DisputeTypedDict": ".dispute",
    "DisputeWithCustomer": ".disputewithcustomer",
    "DisputeWithCustomerCustomer": ".disputewithcustomer",
    "DisputeWithCustomerCustomerTypedDict": ".disputewithcustomer",
    "DisputeWithCustomerObject": ".disputewithcustomer",
    "DisputeWithCustomerStatus": ".disputewithcustomer",
    "DisputeWithCustomerTypedDict": ".disputewithcustomer",
    "Entitlement": ".entitlement",
    "EntitlementBillableMetric": ".entitlement",
    "EntitlementBillableMetricTypedDict": ".entitlement",
    "EntitlementObject": ".entitlement",
    "EntitlementTypedDict": ".entitlement",
    "EntitlementAccessResult": ".entitlementaccessresult",
    "EntitlementAccessResultStatus": ".entitlementaccessresult",
    "EntitlementAccessResultTypedDict": ".entitlementaccessresult",
    "FeatureTypeEnum": ".entitlementaccessresult",
    "EntitlementDetail": ".entitlementdetail",
    "EntitlementDetailTypedDict": ".entitlementdetail",
    "UnknownEntitlementDetail": ".entitlementdetail",
    "EntitlementTemplate": ".entitlementtemplate",
    "EntitlementTemplateBoolean": ".entitlementtemplate",
    "EntitlementTemplateBooleanTypedDict": ".entitlementtemplate",
    "EntitlementTemplateMetered": ".entitlementtemplate",
    "EntitlementTemplateMeteredTypedDict": ".entitlementtemplate",
    "EntitlementTemplateStatic": ".entitlementtemplate",
    "EntitlementTemplateStaticTypedDict": ".entitlementtemplate",
    "EntitlementTemplateTypedDict": ".entitlementtemplate",
    "UsagePeriod": ".entitlementtemplate",
    "UsagePeriodTypedDict": ".entitlementtemplate",
    "EventResponse": ".eventresponse",
    "EventResponseObject": ".eventresponse",
    "EventResponseTypedDict": ".eventresponse",
    "Feature": ".feature",
    "FeatureObject": ".feature",
    "FeatureType": ".feature",
    "FeatureTypedDict": ".feature",
    "Fee": ".fee",
    "FeeObject": ".fee",
    "FeeTypedDict": ".fee",
    "FeePrice": ".feeprice",
    "FeePriceModel": ".feeprice",
    "FeePricePaymentTerm": ".feeprice",
    "FeePriceTypedDict": ".feeprice",
    "Properties": ".feeprice",
    "PropertiesTypedDict": ".feeprice",
    "GeneratePortalLinkRequest": ".generateportallinkop",
    "GeneratePortalLinkRequestBody": ".generateportallinkop",
    "GeneratePortalLinkRequestBodyTypedDict": ".generateportallinkop",
    "GeneratePortalLinkRequestTypedDict": ".generateportallinkop",
    "GetActiveEntitlementsObject": ".getactiveentitlementsop",
    "GetActiveEntitlementsPagination": ".getactiveentitlementsop",
    "GetActiveEntitlementsPaginationTypedDict": ".getactiveentitlementsop",
    "GetActiveEntitlementsRequest": ".getactiveentitlementsop",
    "GetActiveEntitlementsRequestTypedDict": ".getactiveentitlementsop",
    "GetActiveEntitlementsResponse": ".getactiveentitlementsop",
    "GetActiveEntitlementsResponseTypedDict": ".getactiveentitlementsop",
    "GetBillableMetricMeterRequest": ".getbillablemetricmeterop",
    "GetBillableMetricMeterRequestTypedDict": ".getbillablemetricmeterop",
    "WindowSize": ".getbillablemetricmeterop",
    "GetBillableMetricRequest": ".getbillablemetricop",
    "GetBillableMetricRequestTypedDict": ".getbillablemetricop",
    "GetCustomerRequest": ".getcustomerop",
    "GetCustomerRequestTypedDict": ".getcustomerop",
    "GetEntitlementGrantRequest": ".getentitlementgrantop",
    "GetEntitlementGrantRequestTypedDict": ".getentitlementgrantop",
    "GetEntitlementRequest": ".getentitlementop",
    "GetEntitlementRequestTypedDict": ".getentitlementop",
    "GetFeatureRequest": ".getfeatureop",
    "GetFeatureRequestTypedDict": ".getfeatureop",
    "GetFeeRequest": ".getfeeop",
    "GetFeeRequestTypedDict": ".getfeeop",
    "GetFeePriceRequest": ".getfeepriceop",
    "GetFeePriceRequestTypedDict": ".getfeepriceop",
    "GetInvoiceLineItemsRequest": ".getinvoicelineitemsop",
    "GetInvoiceLineItemsRequestTypedDict": ".getinvoicelineitemsop",
    "GetInvoiceRequest": ".getinvoiceop",
    "GetInvoiceRequestTypedDict": ".getinvoiceop",
    "GetPaymentRequest": ".getpaymentop",
    "GetPaymentRequestTypedDict": ".getpaymentop",
    "GetPlanRequest": ".getplanop",
    "GetPlanRequestTypedDict": ".getplanop",
    "GetPriceRequest": ".getpriceop",
    "GetPriceRequestTypedDict": ".getpriceop",
    "GetProductRequest": ".getproductop",
    "GetProductRequestTypedDict": ".getproductop",
    "BucketWidth": ".getrevenueop",
    "GetRevenueRequest": ".getrevenueop",
    "GetRevenueRequestTypedDict": ".getrevenueop",
    "GroupBy": ".getrevenueop",
    "GetSourceRequest": ".getsourceop",
    "GetSourceRequestTypedDict": ".getsourceop",
    "GetSourceRuleRequest": ".getsourceruleop",
    "GetSourceRuleRequestTypedDict": ".getsourceruleop",
    "GetSubscriptionRequest": ".getsubscriptionop",
    "GetSubscriptionRequestTypedDict": ".getsubscriptionop",
    "GetTestClockRequest": ".gettestclockop",
    "GetTestClockRequestTypedDict": ".gettestclockop",
    "GetUsageEventRequest": ".getusageeventop",
    "GetUsageEventRequestTypedDict": ".getusageeventop",
    "GetUserRequest": ".getuserop",
    "GetUserRequestTypedDict": ".getuserop",
    "Grant": ".grant",
    "GrantObject": ".grant",
    "GrantTypedDict": ".grant",
    "GroupInvoiceSummary": ".groupinvoicesummary",
    "GroupInvoiceSummaryTypedDict": ".groupinvoicesummary",
    "GroupTrendEntry": ".grouptrendentry",
    "GroupTrendEntryTypedDict": ".grouptrendentry",
    "IngestEventRequest": ".ingesteventop",
    "IngestEventRequestTypedDict": ".ingesteventop",
    "Invoice": ".invoice",
    "InvoiceObject": ".invoice",
    "InvoiceStatus": ".invoice",
    "InvoiceTypedDict": ".invoice",
    "LineItems": ".invoice",
    "LineItemsTypedDict": ".invoice",
    "Tax": ".invoice",
    "TaxTypedDict": ".invoice",
    "InvoiceCategorySummary": ".invoicecategorysummary",
    "InvoiceCategorySummaryTypedDict": ".invoicecategorysummary",
    "EventType": ".invoicelineitem",
    "InvoiceLineItem": ".invoicelineitem",
    "InvoiceLineItemLineItemType": ".invoicelineitem",
    "InvoiceLineItemTypedDict": ".invoicelineitem",
    "InvoiceLineItemsResponse": ".invoicelineitemsresponse",
    "InvoiceLineItemsResponseTypedDict": ".invoicelineitemsresponse",
    "InvoiceSummary": ".invoicesummary",
    "InvoiceSummaryTypedDict": ".invoicesummary",
    "IssueEntitlementRequest": ".issueentitlementrequest",
    "IssueEntitlementRequestTypedDict": ".issueentitlementrequest",
    "LineItem": ".lineitem",
    "LineItemPaymentTerm": ".lineitem",
    "LineItemStatus": ".lineitem",
    "LineItemType": ".lineitem",
    "LineItemTypedDict": ".lineitem",
    "LineItemsResponse": ".lineitemsresponse",
    "LineItemsResponseObject": ".lineitemsresponse",
    "LineItemsResponseTypedDict": ".lineitemsresponse",
    "LineItemsSummary": ".lineitemssummary",
    "LineItemsSummaryTypedDict": ".lineitemssummary",
    "ListAvailablePlansPagination": ".listavailableplansop",
    "ListAvailablePlansPaginationTypedDict": ".listavailableplansop",
    "ListAvailablePlansRequest": ".listavailableplansop",
    "ListAvailablePlansRequestTypedDict": ".listavailableplansop",
    "ListAvailablePlansResponse": ".listavailableplansop",
    "ListAvailablePlansResponseTypedDict": ".listavailableplansop",
    "ListBillableMetricsObject": ".listbillablemetricsop",
    "ListBillableMetricsPagination": ".listbillablemetricsop",
    "ListBillableMetricsPaginationTypedDict": ".listbillablemetricsop",
    "ListBillableMetricsRequest": ".listbillablemetricsop",
    "ListBillableMetricsRequestTypedDict": ".listbillablemetricsop",
    "ListBillableMetricsResponse": ".listbillablemetricsop",
    "ListBillableMetricsResponseTypedDict": ".listbillablemetricsop",
    "ListCustomersObject": ".listcustomersop",
    "ListCustomersRequest": ".listcustomersop",
    "ListCustomersRequestTypedDict": ".listcustomersop",
    "ListCustomersResponse": ".listcustomersop",
    "ListCustomersResponseTypedDict": ".listcustomersop",
    "ListDisputesObject": ".listdisputesop",
    "ListDisputesPagination": ".listdisputesop",
    "ListDisputesPaginationTypedDict": ".listdisputesop",
    "ListDisputesRequest": ".listdisputesop",
    "ListDisputesRequestTypedDict": ".listdisputesop",
    "ListDisputesResponse": ".listdisputesop",
    "ListDisputesResponseTypedDict": ".listdisputesop",
    "ListDisputesStatus": ".listdisputesop",
    "ListEntitlementGrantsObject": ".listentitlementgrantsop",
    "ListEntitlementGrantsRequest": ".listentitlementgrantsop",
    "ListEntitlementGrantsRequestTypedDict": ".listentitlementgrantsop",
    "ListEntitlementGrantsResponse": ".listentitlementgrantsop",
    "ListEntitlementGrantsResponseTypedDict": ".listentitlementgrantsop",
    "ListEntitlementsObject": ".listentitlementsop",
    "ListEntitlementsRequest": ".listentitlementsop",
    "ListEntitlementsRequestTypedDict": ".listentitlementsop",
    "ListEntitlementsResponse": ".listentitlementsop",
    "ListEntitlementsResponseTypedDict": ".listentitlementsop",
    "ListFeaturesObject": ".listfeaturesop",
    "ListFeaturesPagination": ".listfeaturesop",
    "ListFeaturesPaginationTypedDict": ".listfeaturesop",
    "ListFeaturesRequest": ".listfeaturesop",
    "ListFeaturesRequestTypedDict": ".listfeaturesop",
    "ListFeaturesResponse": ".listfeaturesop",
    "ListFeaturesResponseTypedDict": ".listfeaturesop",
    "ListFeesObject": ".listfeesop",
    "ListFeesPagination": ".listfeesop",
    "ListFeesPaginationTypedDict": ".listfeesop",
    "ListFeesRequest": ".listfeesop",
    "ListFeesRequestTypedDict": ".listfeesop",
    "ListFeesResponse": ".listfeesop",
    "ListFeesResponseTypedDict": ".listfeesop",
    "ListInvoicesObject": ".listinvoicesop",
    "ListInvoicesRequest": ".listinvoicesop",
    "ListInvoicesRequestTypedDict": ".listinvoicesop",
    "ListInvoicesResponse": ".listinvoicesop",
    "ListInvoicesResponseTypedDict": ".listinvoicesop",
    "ListInvoicesStatus": ".listinvoicesop",
    "NextActionAt": ".listinvoicesop",
    "ListLineItemsRequest": ".listlineitemsop",
    "ListLineItemsRequestTypedDict": ".listlineitemsop",
    "ListLineItemsStatus": ".listlineitemsop",
    "ListPaymentsObject": ".listpaymentsop",
    "ListPaymentsRequest": ".listpaymentsop",
    "ListPaymentsRequestTypedDict": ".listpaymentsop",
    "ListPaymentsResponse": ".listpaymentsop",
    "ListPaymentsResponseTypedDict": ".listpaymentsop",
    "ListPaymentsStatus": ".listpaymentsop",
    "ListPlansPagination": ".listplansop",
    "ListPlansPaginationTypedDict": ".listplansop",
    "ListPlansRequest": ".listplansop",
    "ListPlansRequestTypedDict": ".listplansop",
    "ListPlansResponse": ".listplansop",
    "ListPlansResponseTypedDict": ".listplansop",
    "ListPricesPagination": ".listpricesop",
    "ListPricesPaginationTypedDict": ".listpricesop",
    "ListPricesRequest": ".listpricesop",
    "ListPricesRequestTypedDict": ".listpricesop",
    "ListPricesResponse": ".listpricesop",
    "ListPricesResponseTypedDict": ".listpricesop",
    "ListProductsRequest": ".listproductsop",
    "ListProductsRequestTypedDict": ".listproductsop",
    "ListProductsResponse": ".listproductsop",
    "ListProductsResponseTypedDict": ".listproductsop",
    "ListSourceEventsRequest": ".listsourceeventsop",
    "ListSourceEventsRequestTypedDict": ".listsourceeventsop",
    "ListSourceEventsResponse": ".listsourceeventsop",
    "ListSourceEventsResponseTypedDict": ".listsourceeventsop",
    "ListSourceEventsStatus": ".listsourceeventsop",
    "ListSourceRulesRequest": ".listsourcerulesop",
    "ListSourceRulesRequestTypedDict": ".listsourcerulesop",
    "ListSourceRulesResponse": ".listsourcerulesop",
    "ListSourceRulesResponseTypedDict": ".listsourcerulesop",
    "ListSourcesRequest": ".listsourcesop",
    "ListSourcesRequestTypedDict": ".listsourcesop",
    "ListSourcesResponse": ".listsourcesop",
    "ListSourcesResponseTypedDict": ".listsourcesop",
    "ListSubscriptionsRequest": ".listsubscriptionsop",
    "ListSubscriptionsRequestTypedDict": ".listsubscriptionsop",
    "ListSubscriptionsResponse": ".listsubscriptionsop",
    "ListSubscriptionsResponseTypedDict": ".listsubscriptionsop",
    "ListSubscriptionsStatus": ".listsubscriptionsop",
    "ListTestClocksPagination": ".listtestclocksop",
    "ListTestClocksPaginationTypedDict": ".listtestclocksop",
    "ListTestClocksRequest": ".listtestclocksop",
    "ListTestClocksRequestTypedDict": ".listtestclocksop",
    "ListTestClocksResponse": ".listtestclocksop",
    "ListTestClocksResponseTypedDict": ".listtestclocksop",
    "ListUsageEventsObject": ".listusageeventsop",
    "ListUsageEventsRequest": ".listusageeventsop",
    "ListUsageEventsRequestTypedDict": ".listusageeventsop",
    "ListUsageEventsResponse": ".listusageeventsop",
    "ListUsageEventsResponseTypedDict": ".listusageeventsop",
    "MeteredEntitlementDetail": ".meteredentitlementdetail",
    "MeteredEntitlementDetailObject": ".meteredentitlementdetail",
    "MeteredEntitlementDetailStatus": ".meteredentitlementdetail",
    "MeteredEntitlementDetailTypedDict": ".meteredentitlementdetail",
    "OffsetPagination": ".offsetpagination",
    "OffsetPaginationTypedDict": ".offsetpagination",
    "Payment": ".payment",
    "PaymentLineItem": ".payment",
    "PaymentLineItemTypedDict": ".payment",
    "PaymentObject": ".payment",
    "PaymentStatus": ".payment",
    "PaymentTypedDict": ".payment",
    "PaymentSummary": ".paymentsummary",
    "PaymentSummaryTypedDict": ".paymentsummary",
    "Plan": ".plan",
    "PlanObject": ".plan",
    "PlanPaymentTerm": ".plan",
    "PlanPaymentTermTypedDict": ".plan",
    "PlanTypedDict": ".plan",
    "TaxBehavior": ".plan",
    "Price": ".price",
    "PriceModel": ".price",
    "PriceObject": ".price",
    "PricePaymentTerm": ".price",
    "PriceTypedDict": ".price",
    "PriceFeature": ".pricefeature",
    "PriceFeatureFeature": ".pricefeature",
    "PriceFeatureFeatureTypedDict": ".pricefeature",
    "PriceFeatureType": ".pricefeature",
    "PriceFeatureTypedDict": ".pricefeature",
    "PriceFeatureInput": ".pricefeatureinput",
    "PriceFeatureInputTypedDict": ".pricefeatureinput",
    "Function": ".priceproperties_union",
    "Parameters": ".priceproperties_union",
    "ParametersTypedDict": ".priceproperties_union",
    "PriceProperties1": ".priceproperties_union",
    "PriceProperties1TypedDict": ".priceproperties_union",
    "PriceProperties2": ".priceproperties_union",
    "PriceProperties2TypedDict": ".priceproperties_union",
    "PriceProperties3": ".priceproperties_union",
    "PriceProperties3TypedDict": ".priceproperties_union",
    "PriceProperties4": ".priceproperties_union",
    "PriceProperties4TypedDict": ".priceproperties_union",
    "PricePropertiesUnion": ".priceproperties_union",
    "PricePropertiesUnionTypedDict": ".priceproperties_union",
    "Product": ".product",
    "ProductObject": ".product",
    "ProductTypedDict": ".product",
    "PurchaseEntitlementGrantRequest": ".purchaseentitlementgrantop",
    "PurchaseEntitlementGrantRequestTypedDict": ".purchaseentitlementgrantop",
    "PurchaseGrantRequest": ".purchasegrantrequest",
    "PurchaseGrantRequestTypedDict": ".purchasegrantrequest",
    "PaymentSession": ".purchasegrantresponse",
    "PaymentSessionTypedDict": ".purchasegrantresponse",
    "PurchaseGrantResponse": ".purchasegrantresponse",
    "PurchaseGrantResponseObject": ".purchasegrantresponse",
    "PurchaseGrantResponseTypedDict": ".purchasegrantresponse",
    "RefundUsageEventRequest": ".refundusageeventop",
    "RefundUsageEventRequestBody": ".refundusageeventop",
    "RefundUsageEventRequestBodyTypedDict": ".refundusageeventop",
    "RefundUsageEventRequestTypedDict": ".refundusageeventop",
    "RejectSourceEventRequest": ".rejectsourceeventop",
    "RejectSourceEventRequestTypedDict": ".rejectsourceeventop",
    "RevenueSummaryResponse": ".revenuesummaryresponse",
    "RevenueSummaryResponseTypedDict": ".revenuesummaryresponse",
    "RevenueTrendBucket": ".revenuetrendbucket",
    "RevenueTrendBucketTypedDict": ".revenuetrendbucket",
    "From": ".rulecondition",
    "FromTypedDict": ".rulecondition",
    "Operator": ".rulecondition",
    "RuleCondition": ".rulecondition",
    "RuleConditionType": ".rulecondition",
    "RuleConditionTypedDict": ".rulecondition",
    "To": ".rulecondition",
    "ToTypedDict": ".rulecondition",
    "Value": ".rulecondition",
    "ValueTypedDict": ".rulecondition",
    "ValueUnion": ".rulecondition",
    "ValueUnionTypedDict": ".rulecondition",
    "SchemasEntitlement": ".schemas_entitlement",
    "SchemasEntitlementObject": ".schemas_entitlement",
    "SchemasEntitlementStatus": ".schemas_entitlement",
    "SchemasEntitlementTypedDict": ".schemas_entitlement",
    "SchemasPrice": ".schemas_price",
    "SchemasPriceModel": ".schemas_price",
    "SchemasPriceObject": ".schemas_price",
    "SchemasPricePaymentTerm": ".schemas_price",
    "SchemasPriceTypedDict": ".schemas_price",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "ProcessingMode": ".source",
    "Source": ".source",
    "SourceObject": ".source",
    "SourceType": ".source",
    "SourceTypedDict": ".source",
    "SourceEvent": ".sourceevent",
    "SourceEventStatus": ".sourceevent",
    "SourceEventTypedDict": ".sourceevent",
    "SourceRule": ".sourcerule",
    "SourceRuleTypedDict": ".sourcerule",
    "StaticEntitlementDetail": ".staticentitlementdetail",
    "StaticEntitlementDetailObject": ".staticentitlementdetail",
    "StaticEntitlementDetailStatus": ".staticentitlementdetail",
    "StaticEntitlementDetailTypedDict": ".staticentitlementdetail",
    "Breakdown": ".subscription",
    "BreakdownTypedDict": ".subscription",
    "PaymentPaid": ".subscription",
    "PaymentPaidTypedDict": ".subscription",
    "PaymentPending": ".subscription",
    "PaymentPendingTypedDict": ".subscription",
    "PaymentUnion": ".subscription",
    "PaymentUnionTypedDict": ".subscription",
    "Subscription": ".subscription",
    "SubscriptionObject": ".subscription",
    "SubscriptionStatusEnum": ".subscription",
    "SubscriptionTypedDict": ".subscription",
    "UnknownPaymentUnion": ".subscription",
    "SubscriptionPortal": ".subscriptionportal",
    "SubscriptionPortalObject": ".subscriptionportal",
    "SubscriptionPortalTypedDict": ".subscriptionportal",
    "TerminateSubscriptionRequest": ".terminatesubscriptionop",
    "TerminateSubscriptionRequestBody": ".terminatesubscriptionop",
    "TerminateSubscriptionRequestBodyTypedDict": ".terminatesubscriptionop",
    "TerminateSubscriptionRequestTypedDict": ".terminatesubscriptionop",
    "TestClock": ".testclock",
    "TestClockTypedDict": ".testclock",
    "UpdateBillableMetricRequest": ".updatebillablemetricop",
    "UpdateBillableMetricRequestBody": ".updatebillablemetricop",
    "UpdateBillableMetricRequestBodyTypedDict": ".updatebillablemetricop",
    "UpdateBillableMetricRequestTypedDict": ".updatebillablemetricop",
    "TaxRates": ".updatecustomerop",
    "TaxRatesTypedDict": ".updatecustomerop",
    "UpdateCustomerRequest": ".updatecustomerop",
    "UpdateCustomerRequestBody": ".updatecustomerop",
    "UpdateCustomerRequestBodyTypedDict": ".updatecustomerop",
    "UpdateCustomerRequestTypedDict": ".updatecustomerop",
    "UpdateFeatureRequest": ".updatefeatureop",
    "UpdateFeatureRequestBody": ".updatefeatureop",
    "UpdateFeatureRequestBodyTypedDict": ".updatefeatureop",
    "UpdateFeatureRequestTypedDict": ".updatefeatureop",
    "UpdateFeatureType": ".updatefeatureop",
    "UpdateFeeRequest": ".updatefeeop",
    "UpdateFeeRequestBody": ".updatefeeop",
    "UpdateFeeRequestBodyTypedDict": ".updatefeeop",
    "UpdateFeeRequestTypedDict": ".updatefeeop",
    "UpdatePlanRequest": ".updateplanop",
    "UpdatePlanRequestBody": ".updateplanop",
    "UpdatePlanRequestBodyTypedDict": ".updateplanop",
    "UpdatePlanRequestTypedDict": ".updateplanop",
    "UpdatePlanTaxBehavior": ".updateplanop",
    "UpdatePriceModel": ".updatepriceop",
    "UpdatePricePaymentTerm": ".updatepriceop",
    "UpdatePriceRequest": ".updatepriceop",
    "UpdatePriceRequestBody": ".updatepriceop",
    "UpdatePriceRequestBodyTypedDict": ".updatepriceop",
    "UpdatePriceRequestTypedDict": ".updatepriceop",
    "UpdateProductRequest": ".updateproductop",
    "UpdateProductRequestBody": ".updateproductop",
    "UpdateProductRequestBodyTypedDict": ".updateproductop",
    "UpdateProductRequestTypedDict": ".updateproductop",
    "UpdateRuleRequest": ".updaterulerequest",
    "UpdateRuleRequestTypedDict": ".updaterulerequest",
    "UpdateSourceProcessingMode": ".updatesourceop",
    "UpdateSourceRequest": ".updatesourceop",
    "UpdateSourceRequestBody": ".updatesourceop",
    "UpdateSourceRequestBodyTypedDict": ".updatesourceop",
    "UpdateSourceRequestTypedDict": ".updatesourceop",
    "UpdateSourceRuleRequest": ".updatesourceruleop",
    "UpdateSourceRuleRequestTypedDict": ".updatesourceruleop",
    "UpdateUserRequest": ".updateuserop",
    "UpdateUserRequestBody": ".updateuserop",
    "UpdateUserRequestBodyTypedDict": ".updateuserop",
    "UpdateUserRequestTypedDict": ".updateuserop",
    "UpdateUserType": ".updateuserop",
    "Billing": ".usageevent",
    "BillingTypedDict": ".usageevent",
    "Refund": ".usageevent",
    "RefundTypedDict": ".usageevent",
    "UsageEvent": ".usageevent",
    "UsageEventObject": ".usageevent",
    "UsageEventProperty": ".usageevent",
    "UsageEventPropertyTypedDict": ".usageevent",
    "UsageEventTypedDict": ".usageevent",
    "GroupedValue": ".usageresponse",
    "GroupedValueTypedDict": ".usageresponse",
    "UsageResponse": ".usageresponse",
    "UsageResponseObject": ".usageresponse",
    "UsageResponseTypedDict": ".usageresponse",
    "WindowedValue": ".usageresponse",
    "WindowedValueTypedDict": ".usageresponse",
    "State": ".user",
    "User": ".user",
    "UserObject": ".user",
    "UserOrganization": ".user",
    "UserOrganizationTypedDict": ".user",
    "UserType": ".user",
    "UserTypedDict": ".user",
    "Error": ".validationerror",
    "ErrorEnum": ".validationerror",
    "ErrorTypedDict": ".validationerror",
    "ValidTaxAddress": ".validtaxaddress",
    "ValidTaxAddressTypedDict": ".validtaxaddress",
    "VoidEntitlementGrantRequest": ".voidentitlementgrantop",
    "VoidEntitlementGrantRequestTypedDict": ".voidentitlementgrantop",
}


def __getattr__(attr_name: str) -> Any:
    return lazy_getattr(
        attr_name, package=__package__, dynamic_imports=_dynamic_imports
    )


def __dir__():
    return lazy_dir(dynamic_imports=_dynamic_imports)
