"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .invoicecategorysummary import (
    InvoiceCategorySummary,
    InvoiceCategorySummaryTypedDict,
)
from paygentic_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class InvoiceSummaryTypedDict(TypedDict):
    issued: InvoiceCategorySummaryTypedDict
    outstanding: InvoiceCategorySummaryTypedDict
    paid: InvoiceCategorySummaryTypedDict
    written_off: InvoiceCategorySummaryTypedDict


class InvoiceSummary(BaseModel):
    issued: InvoiceCategorySummary

    outstanding: InvoiceCategorySummary

    paid: InvoiceCategorySummary

    written_off: Annotated[InvoiceCategorySummary, pydantic.Field(alias="writtenOff")]


try:
    InvoiceSummary.model_rebuild()
except NameError:
    pass
