"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from paygentic_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class GroupTrendEntryTypedDict(TypedDict):
    group_key: str
    r"""Unique identifier for the group (e.g. plan ID, or 'other')"""
    group_label: str
    r"""Human-readable label for the group (e.g. plan name)"""
    issued_invoices: str
    r"""Total issued invoice amount in dollars for this group in this bucket"""


class GroupTrendEntry(BaseModel):
    group_key: Annotated[str, pydantic.Field(alias="groupKey")]
    r"""Unique identifier for the group (e.g. plan ID, or 'other')"""

    group_label: Annotated[str, pydantic.Field(alias="groupLabel")]
    r"""Human-readable label for the group (e.g. plan name)"""

    issued_invoices: Annotated[str, pydantic.Field(alias="issuedInvoices")]
    r"""Total issued invoice amount in dollars for this group in this bucket"""


try:
    GroupTrendEntry.model_rebuild()
except NameError:
    pass
