"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from paygentic_sdk.types import BaseModel, UNSET_SENTINEL
from paygentic_sdk.utils import FieldMetadata, PathParamMetadata
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DeleteFeeRequestTypedDict(TypedDict):
    id: str
    r"""The unique identifier of the fee"""


class DeleteFeeRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The unique identifier of the fee"""


class DeleteFeeBlockerTypedDict(TypedDict):
    type: NotRequired[str]
    count: NotRequired[int]


class DeleteFeeBlocker(BaseModel):
    type: Optional[str] = None

    count: Optional[int] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["type", "count"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class DeleteFeeDetailsTypedDict(TypedDict):
    blockers: NotRequired[List[DeleteFeeBlockerTypedDict]]


class DeleteFeeDetails(BaseModel):
    blockers: Optional[List[DeleteFeeBlocker]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["blockers"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
