"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .sourcerule import SourceRule, SourceRuleTypedDict
from paygentic_sdk.types import BaseModel, UNSET_SENTINEL
from paygentic_sdk.utils import FieldMetadata, QueryParamMetadata
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ListSourceRulesRequestTypedDict(TypedDict):
    source_id: str
    r"""Filter rules by source ID"""


class ListSourceRulesRequest(BaseModel):
    source_id: Annotated[
        str,
        pydantic.Field(alias="sourceId"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ]
    r"""Filter rules by source ID"""


class ListSourceRulesResponseTypedDict(TypedDict):
    r"""List of rules"""

    data: NotRequired[List[SourceRuleTypedDict]]


class ListSourceRulesResponse(BaseModel):
    r"""List of rules"""

    data: Optional[List[SourceRule]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["data"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
