"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from paygentic_sdk.types import BaseModel
from paygentic_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing_extensions import Annotated, TypedDict


class GetEntitlementGrantRequestTypedDict(TypedDict):
    entitlement_id: str
    r"""The unique identifier of the entitlement."""
    grant_id: str
    r"""The unique identifier of the grant."""


class GetEntitlementGrantRequest(BaseModel):
    entitlement_id: Annotated[
        str,
        pydantic.Field(alias="entitlementId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The unique identifier of the entitlement."""

    grant_id: Annotated[
        str,
        pydantic.Field(alias="grantId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The unique identifier of the grant."""
